@@ -132,6 +132,25 @@ QT_BEGIN_NAMESPACE
  * \sa title, titleVisible
  */
 
+/*!
+ * \qmlproperty bool Abstract3DAxis::scaleLabelsByCount
+ * \since 6.9
+ *
+ * Whether the labels will automatically adjust their size based on the total amount of labels.
+ *
+ * \sa labelSize
+ */
+
+/*!
+ * \qmlproperty real Abstract3DAxis::labelSize
+ * \since 6.9
+ *
+ * The size of the label.
+ * The default for this value is \c 1.0.
+ *
+ * \sa scaleLabelsByCount
+ */
+
 /*!
     \qmlsignal Abstract3DAxis::titleChanged(string newTitle)
 
@@ -199,6 +218,18 @@ QT_BEGIN_NAMESPACE
     This signal is emitted when the titleOffset property value changes to
     \a offset.
 */
+/*!
+    \qmlsignal Abstract3DAxis::scaleLabelsByCountChanged(bool adjust)
+
+    This signal is emitted when the scaleLabelsByCount property value changes to
+    \a adjust.
+*/
+/*!
+    \qmlsignal Abstract3DAxis::labelSizeChanged(real size)
+
+    This signal is emitted when the labelSize property value changes to
+    \a size.
+*/
 
 /*!
  * \enum QAbstract3DAxis::AxisOrientation
@@ -490,6 +521,54 @@ bool QAbstract3DAxis::isAutoAdjustRange() const
     return d->m_autoAdjust;
 }
 
+/*!
+ * \property QAbstract3DAxis::scaleLabelsByCount
+ * \since 6.9
+ * \brief Whether the labels will automatically adjust their size
+ * based on the total amount of labels
+ *
+ * \sa labelSize()
+ */
+void QAbstract3DAxis::setScaleLabelsByCount(bool adjust)
+{
+    Q_D(QAbstract3DAxis);
+    if (d->m_scaleLabelsByCount != adjust) {
+        d->m_scaleLabelsByCount = adjust;
+        emit scaleLabelsByCountChanged(adjust);
+    }
+}
+
+bool QAbstract3DAxis::isScaleLabelsByCount() const
+{
+    Q_D(const QAbstract3DAxis);
+    return d->m_scaleLabelsByCount;
+}
+
+/*!
+ * \property QAbstract3DAxis::labelSize
+ * \since 6.9
+ * \brief Size of the label
+ *
+ * The size of the label.
+ * The default for this value is \c 1.0.
+ *
+ * \sa scaleLabelsByCount
+ */
+void QAbstract3DAxis::setLabelSize(qreal size)
+{
+    Q_D(QAbstract3DAxis);
+    if (d->m_labelSize != size) {
+        d->m_labelSize = size;
+        emit labelSizeChanged(size);
+    }
+}
+
+qreal QAbstract3DAxis::labelSize() const
+{
+    Q_D(const QAbstract3DAxis);
+    return d->m_labelSize;
+}
+
 /*!
  * \property QAbstract3DAxis::titleOffset
  *
@@ -531,6 +610,8 @@ QAbstract3DAxisPrivate::QAbstract3DAxisPrivate(QAbstract3DAxis::AxisType type)
     , m_min(0.0f)
     , m_max(10.0f)
     , m_autoAdjust(true)
+    , m_scaleLabelsByCount(false)
+    , m_labelSize(1.0)
     , m_labelAutoAngle(0.0f)
     , m_titleOffset(0.0f)
     , m_titleVisible(false)
